==> ktorrent-5.0.tar.xz: ktorrent-5.0/libktcore/ktversion.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef KTVERSION_HH
#define KTVERSION_HH

#include <version.h>
#include "util/constants.h"

#define KT_VERSION_MACRO "5.0"

namespace kt
{
    const bt::Uint32 MAJOR = 5;
    const bt::Uint32 MINOR = 0;
    const bt::Uint32 RELEASE = 0;
    const bt::VersionType VERSION_TYPE = bt::DEVEL;
    const char VERSION_STRING[] = KT_VERSION_MACRO;
}



#endif

==> ktorrent-5.0.1.tar.xz: ktorrent-5.0.1/libktcore/ktversion.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef KTVERSION_HH
#define KTVERSION_HH

#include <version.h>
#include "util/constants.h"

#define KT_VERSION_MACRO "5.0.1"

namespace kt
{
    const bt::Uint32 MAJOR = 5;
    const bt::Uint32 MINOR = 0;
    const bt::Uint32 RELEASE = 1;
    const bt::VersionType VERSION_TYPE = bt::DEVEL;
    const char VERSION_STRING[] = KT_VERSION_MACRO;
}



#endif
